@@ -50,19 +50,6 @@ require_host_getent () {
     host_getent="$AUTOPKGTEST_TMP/libc-bin/usr/bin/getent"
 }
 
-require_apt_jessie () {
-    mirror="$(perl -ne 'print $1 if m{^deb\s+http://([-\w.:]+)/debian/?\s}' /etc/apt/sources.list /etc/apt/sources.list.d/*)"
-    if [ -n "$mirror" ]; then
-        echo >> /etc/apt/sources.list
-        echo "deb http://$mirror/debian jessie main" >> /etc/apt/sources.list
-    else
-        echo "1..0 # SKIP - unable to guess how to set up an apt source for jessie" >&7
-        exit 77
-    fi
-
-    require_apt
-}
-
 require_apt () {
     local arch="${1-}"
 
@@ -160,8 +147,30 @@ assert_hosts () {
     fi
 }
 
-get_resolve_rune () {
-    perl -ne 'print $1 if /^hosts:.*\s(resolve(?:\s+\[!?[A-Z]+=[a-z]+\])?)/' /etc/nsswitch.conf
+assert_hosts_matches () {
+    local pattern="$1"
+    local really="$(perl -ne 'print if /^hosts:/' /etc/nsswitch.conf)"
+    test_num=$(( $test_num + 1 ))
+
+    if perl -e "\$_ = shift; exit 1 unless /^$pattern\$/" "$really"; then
+        echo "ok $test_num - “$really” in nsswitch.conf matches “$pattern” as expected" >&7
+    else
+        echo "not ok $test_num - expected “$pattern” in nsswitch.conf, got “$really”" >&7
+        fail=1
+    fi
+}
+
+assert_hosts_does_not_match () {
+    local pattern="$1"
+    local really="$(perl -ne 'print if /^hosts:/' /etc/nsswitch.conf)"
+    test_num=$(( $test_num + 1 ))
+
+    if perl -e "\$_ = shift; exit 1 if /$pattern/" "$really"; then
+        echo "ok $test_num - “$really” in nsswitch.conf does not match “$pattern”, as expected" >&7
+    else
+        echo "not ok $test_num - did not expect “$pattern” in nsswitch.conf, but got “$really”" >&7
+        fail=1
+    fi
 }
 
 ok () {
